# Changelog

<!--next-version-placeholder-->

## v0.7.0 (2024-02-14)

### Feature

* Introducing generic pipeline, Kf/generic pipeline ([#59](https://github.com/centre-for-humanities-computing/conspiracies/issues/59)) ([`13c514e`](https://github.com/centre-for-humanities-computing/conspiracies/commit/13c514e4c2f1e26123599200de8e8d83855a1b24))

## v0.6.0 (2023-11-02)

### Feature

* Bump version after reorganization of package structure, optimizations and re-design of relation triplet data model ([`353d285`](https://github.com/centre-for-humanities-computing/conspiracies/commit/353d2852039087ee60f835bf8b582c88336ccd82))

## v0.5.2 (2023-10-18)

### Fix

* Avoid downloading model for tests ([`340d6f0`](https://github.com/centre-for-humanities-computing/conspiracies/commit/340d6f05ae6c8e202474557844e566fe1d9afa46))

## v0.5.1 (2023-10-10)

### Fix

* Bump version ([`ff2a1d9`](https://github.com/centre-for-humanities-computing/conspiracies/commit/ff2a1d924abb03acee12204fb6f3643f4e36de21))

## v0.5.0 (2023-03-31)
### Feature
* Added gold data to package data ([`b892aaa`](https://github.com/centre-for-humanities-computing/conspiracies/commit/b892aaaa83a73e2074485ec5cd40df08d95b9c65))
* Fixed spacy dep. to allow for the visualizer ([`375b3bf`](https://github.com/centre-for-humanities-computing/conspiracies/commit/375b3bf96fa4dd1704fe2fb079541b0cbbce05f3))
* Added triplet data classes along with seraliazation functions ([`0325c63`](https://github.com/centre-for-humanities-computing/conspiracies/commit/0325c63c1c6c8dfb36c7ba21edda87ab575f6a04))

### Fix
* Fixed circular import ([`bfc5595`](https://github.com/centre-for-humanities-computing/conspiracies/commit/bfc5595ead67bdb7ac3bbb8c3fa585dc552efcec))
* Prevented circular import ([`2af3559`](https://github.com/centre-for-humanities-computing/conspiracies/commit/2af3559f337e38eb8b07b6dc04d8e264df634b72))

### Documentation
* Changed req. for docs ([`dcf2a1c`](https://github.com/centre-for-humanities-computing/conspiracies/commit/dcf2a1c8e46c4687e7e7b47a5bf8b40d393e8644))
* Updated tutorial based on reivew ([`0f29203`](https://github.com/centre-for-humanities-computing/conspiracies/commit/0f292036efa842f5f729ff31f152671ecdd8522f))
* Updated docstring based on review comments ([`b669555`](https://github.com/centre-for-humanities-computing/conspiracies/commit/b6695557426dd47a4fb10433de586d210478c47d))
* Updated tutorial to reflect changes ([`833ceae`](https://github.com/centre-for-humanities-computing/conspiracies/commit/833ceae49c83cbc44ecedd97a7cdd4262609c1a0))
* Increased execution time for tutorial ([`4fee404`](https://github.com/centre-for-humanities-computing/conspiracies/commit/4fee4042d6a7704b426b6f563aeee51b0b79ae57))
* Updated notebook ([`330fc22`](https://github.com/centre-for-humanities-computing/conspiracies/commit/330fc22efba02f05958cd51993ff404f14ba5036))
* Updated to properly read data ([`3e3e62d`](https://github.com/centre-for-humanities-computing/conspiracies/commit/3e3e62d7ed22b44492661447cb00f7c516893e9d))
* Added reading gold as an example ([`b6d83b6`](https://github.com/centre-for-humanities-computing/conspiracies/commit/b6d83b61119c0f644abdd7659396f552cb7ffded))

## v0.4.0 (2023-03-10)
### Feature
* Add meaningful default task descriptions for templates ([#20](https://github.com/centre-for-humanities-computing/conspiracies/issues/20)) ([`17436ee`](https://github.com/centre-for-humanities-computing/conspiracies/commit/17436eefd5a0bb83f223cb8f67c6db44105ffdda))

## v0.3.1 (2023-03-08)
### Fix
* Fixed circular import ([`bc2a0f7`](https://github.com/centre-for-humanities-computing/conspiracies/commit/bc2a0f782e96e0f9d70654fa9b6af666e8606b62))

## v0.3.0 (2023-02-24)
### Feature
* Added gold data to package data ([`ce66666`](https://github.com/centre-for-humanities-computing/conspiracies/commit/ce6666655d9c110216ba1c034d37fc8636e2ff0e))
* Fixed spacy dep. to allow for the visualizer ([`2545e74`](https://github.com/centre-for-humanities-computing/conspiracies/commit/2545e74c1157c7be8765061e34cecb0e4ff27a8b))
* Added triplet data classes along with seraliazation functions ([`4f97496`](https://github.com/centre-for-humanities-computing/conspiracies/commit/4f974969f1b7ab7c8883be1160aeec94c8408279))
* Initial string_matchup.py ([`dd378b7`](https://github.com/centre-for-humanities-computing/conspiracies/commit/dd378b757b5b23703124e7ae5831917d64d200b9))

### Fix
* Prevented circular import ([`2a0a5ea`](https://github.com/centre-for-humanities-computing/conspiracies/commit/2a0a5ea3291b101054b72bef15cd68a2db1d5a50))
* String matchup now works as intended ([`5c49c29`](https://github.com/centre-for-humanities-computing/conspiracies/commit/5c49c2996cd1b658dadbb9d9110a87e7f75b2126))

### Documentation
* Changed req. for docs ([`0fc5f41`](https://github.com/centre-for-humanities-computing/conspiracies/commit/0fc5f418b29cee332efc73ad156e727bcb34b4a0))
* Updated tutorial based on reivew ([`71c8f75`](https://github.com/centre-for-humanities-computing/conspiracies/commit/71c8f75ce6ddd8136fc2beb27a3ec05b95b842fe))
* Updated docstring based on review comments ([`c96325f`](https://github.com/centre-for-humanities-computing/conspiracies/commit/c96325f82b9b671daf118b8913a244cd95d93582))
* Updated tutorial to reflect changes ([`3544f39`](https://github.com/centre-for-humanities-computing/conspiracies/commit/3544f395955a211afbf9eb03350ab8f189685366))
* Add Data documentation ([#12](https://github.com/centre-for-humanities-computing/conspiracies/issues/12)) ([`856d28f`](https://github.com/centre-for-humanities-computing/conspiracies/commit/856d28f63aeb738afe02a316ce7ca39338c04f32))
* Increased execution time for tutorial ([`159b9ee`](https://github.com/centre-for-humanities-computing/conspiracies/commit/159b9ee5fc18f3605be705327aa8afdb335d3164))
* Updated notebook ([`e411258`](https://github.com/centre-for-humanities-computing/conspiracies/commit/e411258b70ae3280a28ede25dca8f8e56fa86f37))
* Updated to properly read data ([`5f8ef0b`](https://github.com/centre-for-humanities-computing/conspiracies/commit/5f8ef0b0d05338c02a019cb7fa02386733e43b77))
* Added reading gold as an example ([`f7032e7`](https://github.com/centre-for-humanities-computing/conspiracies/commit/f7032e726541f932fba0088a91a36531c60a7f87))
* Updated overview with some meta data ([`bf65d0c`](https://github.com/centre-for-humanities-computing/conspiracies/commit/bf65d0cd896c323871eccb11b5e2eec0a81e09d1))
* Fix icon in dark mode ([`88dc2b5`](https://github.com/centre-for-humanities-computing/conspiracies/commit/88dc2b55a9ed25a871983ca96a3acda53edadc2c))
* Added logo to readme ([`18f5c0f`](https://github.com/centre-for-humanities-computing/conspiracies/commit/18f5c0f5b177b01e2f3b8dedbc0181c8e7bb076b))
* Added code of conduct ([`122b970`](https://github.com/centre-for-humanities-computing/conspiracies/commit/122b9702d4b22780e456f17a64d5f0590cb7b014))

## v0.2.3 (2023-02-04)
### Fix
* Semantic release test ([`0d85b67`](https://github.com/centre-for-humanities-computing/conspiracies/commit/0d85b67196820325b1b76051e149a6131d03044c))

### Documentation
* Added changelog ([`909bb6b`](https://github.com/centre-for-humanities-computing/conspiracies/commit/909bb6bb26fbf0c8ff5c2b61fc328aa7d78676d1))
* Updated links ([`f7598f5`](https://github.com/centre-for-humanities-computing/conspiracies/commit/f7598f5bc27ab806d3f0a2806dae7050da07c64b))

## v0.2.2 (2023-02-03)

Initial commit of the project after resetting the GitHub repository.